==> cscec5b-op-impl-3.0.0-20220921.085300-6-sources.jar: com/ejianc/business/op/vo/ApplyReportVO.java <==
package com.ejianc.business.op.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 申请实体
 *
 * @author generator
 *
 */
public class ApplyReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Integer billState; // 单据状态（审批必须字段）
    private String billCode; // 单据编号
    private Long orgId; // 组织主键
    private Long projectId; // 项目主键
    private String projectName; // 项目名称
    private String applyDept; // 申请单位
    private String carNumber; // 车牌号
    private Date outDate; // 出场日期
    private String applyUser; // 申请人
    private String tel; // 电话
    private Integer opStatus; // 出门状态 0-暂存 1-保存 2-审批中 3-待核验  4-待确认 5-核验不通过  6-已出门 7-确认不通过
    private String opStatusName;
    private String tpurl; // 现场照片URL
    private String qrcode; // 二维码信息
    private String checkNote; // 核验说明
    private String hyurl; // 核验照片URL
    private Date checkTime; // 核验时间
    private String checkerOpenId; // 核验人openid
    private Long checkerId; // 核验人ID
    private String checkerName; // 核验人姓名
    private String confirmNote; // 确认说明
    private String qrurl; // 确认照片URL
    private String confirmerOpenId; // 确认人openid
    private Date confirmTime; // 确认时间
    private Long confirmerId; // 确认人ID
    private String confirmerName; // 确认人姓名
    private Integer insideFlag; // 是否内部人员(0-否 1-是)
    private Long userId; // 用户主键
    private Long guardUserId; // 门岗用户主键
    private String openId; // openid
    private Integer outType; // 出场类型(1-分包物资、2-租赁材退场、3-废旧物资处理、4-维修、5-调拨退场、6-其他)
    private String outTypeName;
    private Integer branchCorpId; // 所属公司主键
    private String branchCorpName; // 所属公司名称

    private String code; // 编码
    private String name; // 名称
    private String spec; // 型号
    private String unit; // 单位
    private BigDecimal num; // 数量
    private String reason; // 出场原因
    private String memo; // 备注

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getApplyDept() {
        return applyDept;
    }

    public void setApplyDept(String applyDept) {
        this.applyDept = applyDept;
    }
    public String getCarNumber() {
        return carNumber;
    }

    public void setCarNumber(String carNumber) {
        this.carNumber = carNumber;
    }
    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }
    public String getApplyUser() {
        return applyUser;
    }

    public void setApplyUser(String applyUser) {
        this.applyUser = applyUser;
    }
    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }
    public Integer getOpStatus() {
        return opStatus;
    }

    public void setOpStatus(Integer opStatus) {
        this.opStatus = opStatus;
    }
    public String getTpurl() {
        return tpurl;
    }

    public void setTpurl(String tpurl) {
        this.tpurl = tpurl;
    }
    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }
    public String getCheckNote() {
        return checkNote;
    }

    public void setCheckNote(String checkNote) {
        this.checkNote = checkNote;
    }
    public String getHyurl() {
        return hyurl;
    }

    public void setHyurl(String hyurl) {
        this.hyurl = hyurl;
    }
    public Date getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(Date checkTime) {
        this.checkTime = checkTime;
    }
    public Long getCheckerId() {
        return checkerId;
    }

    public void setCheckerId(Long checkerId) {
        this.checkerId = checkerId;
    }
    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }
    public String getConfirmNote() {
        return confirmNote;
    }

    public void setConfirmNote(String confirmNote) {
        this.confirmNote = confirmNote;
    }
    public String getQrurl() {
        return qrurl;
    }

    public void setQrurl(String qrurl) {
        this.qrurl = qrurl;
    }
    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }
    public Long getConfirmerId() {
        return confirmerId;
    }

    public void setConfirmerId(Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    public String getConfirmerName() {
        return confirmerName;
    }

    public void setConfirmerName(String confirmerName) {
        this.confirmerName = confirmerName;
    }
    public Integer getInsideFlag() {
        return insideFlag;
    }

    public void setInsideFlag(Integer insideFlag) {
        this.insideFlag = insideFlag;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public Long getGuardUserId() {
        return guardUserId;
    }

    public void setGuardUserId(Long guardUserId) {
        this.guardUserId = guardUserId;
    }
    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }
    public Integer getOutType() {
        return outType;
    }

    public void setOutType(Integer outType) {
        this.outType = outType;
    }
    public Integer getBranchCorpId() {
        return branchCorpId;
    }

    public void setBranchCorpId(Integer branchCorpId) {
        this.branchCorpId = branchCorpId;
    }
    public String getBranchCorpName() {
        return branchCorpName;
    }

    public void setBranchCorpName(String branchCorpName) {
        this.branchCorpName = branchCorpName;
    }

    public String getCheckerOpenId() {
        return checkerOpenId;
    }

    public void setCheckerOpenId(String checkerOpenId) {
        this.checkerOpenId = checkerOpenId;
    }

    public String getConfirmerOpenId() {
        return confirmerOpenId;
    }

    public void setConfirmerOpenId(String confirmerOpenId) {
        this.confirmerOpenId = confirmerOpenId;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getOpStatusName() {
        return opStatusName;
    }

    public void setOpStatusName(String opStatusName) {
        this.opStatusName = opStatusName;
    }

    public String getOutTypeName() {
        return outTypeName;
    }

    public void setOutTypeName(String outTypeName) {
        this.outTypeName = outTypeName;
    }
}

==> cscec5b-op-impl-3.0.0-20240123.100749-70-sources.jar: com/ejianc/business/op/vo/ApplyReportVO.java <==
package com.ejianc.business.op.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 申请实体
 *
 * @author generator
 *
 */
public class ApplyReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mainId;
    private Integer billState; // 单据状态（审批必须字段）
    private String billCode; // 单据编号
    private Long orgId; // 组织主键
    private Long projectId; // 项目主键
    private String projectName; // 项目名称
    private String applyDept; // 申请单位
    private String carNumber; // 车牌号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date outDate; // 出场日期
    private String applyUser; // 申请人
    private String tel; // 电话
    private Integer opStatus; // 出门状态 0-暂存 1-保存 2-审批中 3-待核验  4-待确认 5-核验不通过  6-已出门 7-确认不通过
    private String opStatusName;
    private String tpurl; // 现场照片URL
    private String qrcode; // 二维码信息
    private String checkNote; // 核验说明
    private String hyurl; // 核验照片URL
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date checkTime; // 核验时间
    private String checkerOpenId; // 核验人openid
    private Long checkerId; // 核验人ID
    private String checkerName; // 核验人姓名
    private String confirmNote; // 确认说明
    private String qrurl; // 确认照片URL
    private String confirmerOpenId; // 确认人openid
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date confirmTime; // 确认时间
    private Long confirmerId; // 确认人ID
    private String confirmerName; // 确认人姓名
    private Integer insideFlag; // 是否内部人员(0-否 1-是)
    private Long userId; // 用户主键
    private Long guardUserId; // 门岗用户主键
    private String openId; // openid
    private Integer outType; // 出场类型(1-分包物资、2-租赁材退场、3-废旧物资处理、4-维修、5-调拨退场、6-其他)
    private String outTypeName;
    private Long branchCorpId; // 所属公司主键
    private String branchCorpName; // 所属公司名称

    private String code; // 编码
    private String name; // 名称
    private String spec; // 型号
    private String unit; // 单位
    private BigDecimal num; // 数量
    private String reason; // 出场原因
    private String memo; // 备注

    public Long getMainId() {
        return mainId;
    }

    public void setMainId(Long mainId) {
        this.mainId = mainId;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getApplyDept() {
        return applyDept;
    }

    public void setApplyDept(String applyDept) {
        this.applyDept = applyDept;
    }
    public String getCarNumber() {
        return carNumber;
    }

    public void setCarNumber(String carNumber) {
        this.carNumber = carNumber;
    }
    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }
    public String getApplyUser() {
        return applyUser;
    }

    public void setApplyUser(String applyUser) {
        this.applyUser = applyUser;
    }
    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }
    public Integer getOpStatus() {
        return opStatus;
    }

    public void setOpStatus(Integer opStatus) {
        this.opStatus = opStatus;
    }
    public String getTpurl() {
        return tpurl;
    }

    public void setTpurl(String tpurl) {
        this.tpurl = tpurl;
    }
    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }
    public String getCheckNote() {
        return checkNote;
    }

    public void setCheckNote(String checkNote) {
        this.checkNote = checkNote;
    }
    public String getHyurl() {
        return hyurl;
    }

    public void setHyurl(String hyurl) {
        this.hyurl = hyurl;
    }
    public Date getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(Date checkTime) {
        this.checkTime = checkTime;
    }
    public Long getCheckerId() {
        return checkerId;
    }

    public void setCheckerId(Long checkerId) {
        this.checkerId = checkerId;
    }
    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }
    public String getConfirmNote() {
        return confirmNote;
    }

    public void setConfirmNote(String confirmNote) {
        this.confirmNote = confirmNote;
    }
    public String getQrurl() {
        return qrurl;
    }

    public void setQrurl(String qrurl) {
        this.qrurl = qrurl;
    }
    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }
    public Long getConfirmerId() {
        return confirmerId;
    }

    public void setConfirmerId(Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    public String getConfirmerName() {
        return confirmerName;
    }

    public void setConfirmerName(String confirmerName) {
        this.confirmerName = confirmerName;
    }
    public Integer getInsideFlag() {
        return insideFlag;
    }

    public void setInsideFlag(Integer insideFlag) {
        this.insideFlag = insideFlag;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public Long getGuardUserId() {
        return guardUserId;
    }

    public void setGuardUserId(Long guardUserId) {
        this.guardUserId = guardUserId;
    }
    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }
    public Integer getOutType() {
        return outType;
    }

    public void setOutType(Integer outType) {
        this.outType = outType;
    }
    public Long getBranchCorpId() {
        return branchCorpId;
    }

    public void setBranchCorpId(Long branchCorpId) {
        this.branchCorpId = branchCorpId;
    }
    public String getBranchCorpName() {
        return branchCorpName;
    }

    public void setBranchCorpName(String branchCorpName) {
        this.branchCorpName = branchCorpName;
    }

    public String getCheckerOpenId() {
        return checkerOpenId;
    }

    public void setCheckerOpenId(String checkerOpenId) {
        this.checkerOpenId = checkerOpenId;
    }

    public String getConfirmerOpenId() {
        return confirmerOpenId;
    }

    public void setConfirmerOpenId(String confirmerOpenId) {
        this.confirmerOpenId = confirmerOpenId;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getOpStatusName() {
        return opStatusName;
    }

    public void setOpStatusName(String opStatusName) {
        this.opStatusName = opStatusName;
    }

    public String getOutTypeName() {
        return outTypeName;
    }

    public void setOutTypeName(String outTypeName) {
        this.outTypeName = outTypeName;
    }
}
